#include <Redis_Provider.h>

using namespace inaf::oasbo::Providers;

RedisProviderBuilder::RedisProviderBuilder() {
	this->reset();
}
RedisProviderBuilder::RedisProviderBuilder(std::string ip, int port, std::string topic) {
	this->provider = new RedisProvider(ip, port, topic);

}
RedisProviderBuilder::~RedisProviderBuilder() {
	delete provider;
}

void RedisProviderBuilder::reset() {
	this->provider = new RedisProvider();
}

RedisProviderBuilder* RedisProviderBuilder::configFrom(Configurators::BaseConfigurator *conf) {
	conf->readConfigFromSource(config_target);
	std::map<std::string, std::string> params = conf->getConfig();

	std::string key = config_target+"_"+ip_key;
	if (params.count(key) > 0)
		provider->ip = params[key];

	key = config_target+"_"+port_key;
	if (params.count(key) > 0)
		provider->port = std::stoi(params[key]);

	key = config_target+"_"+redis_key_key;
	if (params.count(key) > 0)
		provider->setDest(params[key]);
	return this;
}

RedisProviderBuilder* RedisProviderBuilder::setIp(std::string ip) {
	provider->ip = ip;
	return this;
}

RedisProviderBuilder* RedisProviderBuilder::setPort(int port) {
	provider->port = port;
	return this;
}

RedisProviderBuilder* RedisProviderBuilder::setKey(std::string key) {
	provider->setDest(key);
	return this;
}

RedisProvider* RedisProviderBuilder::getProvider() {
	RedisProvider *result = this->provider;
	this->reset();
	return result;
}
